@@ -38,10 +38,10 @@ CscopeMsgDlg::CscopeMsgDlg(TQWidget* pParent, const char* szName)
 	: CscopeMsgLayout(pParent, szName, false, 0)
 {
 	// Hide the dialog when the "Hide" button is clicked
-	connect(m_pHideButton, SIGNAL(clicked()), this, SLOT(hide()));
+	connect(m_pHideButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(hide()));
 	
 	// Clear all messages when the "Clear" button is clicked
-	connect(m_pClearButton, SIGNAL(clicked()), m_pMsgText, SLOT(clear()));
+	connect(m_pClearButton, TQ_SIGNAL(clicked()), m_pMsgText, TQ_SLOT(clear()));
 }
 
 /**
