@@ -56,8 +56,8 @@ QueryPage::QueryPage(TQWidget* pParent, const char * szName) :
 	m_pView = new QueryView(this);
 	m_pDriver = new QueryViewDriver(m_pView, this);
 	
-	connect(m_pView, SIGNAL(lineRequested(const TQString&, uint)), this,
-		SIGNAL(lineRequested(const TQString&, uint)));
+	connect(m_pView, TQ_SIGNAL(lineRequested(const TQString&, uint)), this,
+		TQ_SIGNAL(lineRequested(const TQString&, uint)));
 	
 	// Set colours and font
 	applyPrefs();
