@@ -44,7 +44,7 @@
 
 class QueryWidget : public QueryWidgetLayout
 {
-   Q_OBJECT
+   TQ_OBJECT
 
 public:
 	QueryWidget(TQWidget* pParent = 0, const char* szName = 0);
